# 版本发布
---

## V 0.2 (2022-04-28)

> 内部测试版本

#### 1、新增功能：

* 配置文件：支持配置文件的读取
* 用例执行器：支持pytest的参数化和自定义参数
* 测试用例：支持pytest的fixture、mark、skip等功能
*

#### 2、功能优化

* 无

#### 3、Bug修复

* 无

---

## V 0.1 (2022-03-31)

> 内部测试版本

#### 1、新增功能：

* 数据构造：支持Data下的Mysql、Redis、yaml、csv 等功能装饰器
* 测试报告：支持在本项目中，生成html测试报告
* 插件支持：支持pytest的钩子插件
* 拓展支持：支持邮件、微信推送、执行日志
* 用例执行器： 支持pytest全部和单个用例的执行器

#### 2、功能优化

* 无

#### 3、Bug修复

* 无

---